@@ -31,7 +31,7 @@ def check_tlc(
 ) -> CheckResult:
 
     if do_parse is True:
-        parse(tla_file_name=tla_file_name, files=files)
+        parse(tla_file_name=tla_file_name, files=files, args=args)
 
     json_command = wrap_command(
         cmd=const_values.CHECK_CMD,
@@ -76,10 +76,10 @@ def check_apalache(
     check_logger.debug(f"- traces_dir: {traces_dir}")
 
     if do_parse is True:
-        parse(tla_file_name, files)
+        parse(tla_file_name, files, args)
 
     if do_typecheck is True:
-        typecheck(tla_file_name, files)
+        typecheck(tla_file_name, files, args)
 
     json_command = wrap_command(
         cmd=const_values.CHECK_CMD,
