@@ -4,6 +4,7 @@ from pathlib import Path
 from timeit import default_timer as timer
 from typing import Dict, List, Optional
 
+import semver
 import typer
 
 from modelator import ModelResult, __version__, const_values
@@ -42,7 +43,9 @@ def common(
     pass
 
 
-def _create_and_parse_model(model_path: str, init="Init", next="Next", constants={}):
+def _create_and_parse_model(
+    model_path: str, init="Init", next="Next", constants={}, *, args: Dict[str, str]
+):
     try:
         model = Model(model_path, init, next, constants=constants)
     except ValueError:
@@ -52,7 +55,7 @@ def _create_and_parse_model(model_path: str, init="Init", next="Next", constants
     model.files_contents = tla_helpers.get_auxiliary_tla_files(model_path)
 
     try:
-        model.parse()
+        model.parse(args=args)
     except ModelParsingError as e:
         print("Parsing error 💥")
         print(e)
@@ -61,8 +64,11 @@ def _create_and_parse_model(model_path: str, init="Init", next="Next", constants
     return model
 
 
-@app.command()
+@app.command(
+    context_settings={"allow_extra_args": True, "ignore_unknown_options": True}
+)
 def load(
+    ctx: typer.Context,
     path: str = typer.Argument(..., help="Path to a TLA+ model file."),
     config_path: Optional[str] = typer.Option(
         None,
@@ -85,7 +91,9 @@ def load(
         )
 
     print(f"Loading {path}... ")
-    model = _create_and_parse_model(path)
+    extra_args = [arg[2:] for arg in ctx.args if arg.startswith("--")]
+    extra_args = _parse_list_of_assignments(extra_args)
+    model = _create_and_parse_model(path, args=extra_args)
 
     config = None
     if config_path:
@@ -100,8 +108,12 @@ def load(
     print("Loading OK ✅")
 
 
-@app.command()
-def reload():
+@app.command(
+    context_settings={"allow_extra_args": True, "ignore_unknown_options": True}
+)
+def reload(
+    ctx: typer.Context,
+):
     """
     Reload model and configuration files, if any.
     """
@@ -113,7 +125,9 @@ def reload():
     model_path = model.tla_file_path
 
     print(f"Reloading {model_path}... ")
-    model = _create_and_parse_model(model_path)
+    extra_args = [arg[2:] for arg in ctx.args if arg.startswith("--")]
+    extra_args = _parse_list_of_assignments(extra_args)
+    model = _create_and_parse_model(model_path, args=extra_args)
 
     if config_path:
         print(f"Loading {config_path}... ")
@@ -127,8 +141,12 @@ def reload():
     print("Loading OK ✅")
 
 
-@app.command()
-def typecheck():
+@app.command(
+    context_settings={"allow_extra_args": True, "ignore_unknown_options": True}
+)
+def typecheck(
+    ctx: typer.Context,
+):
     """
     Type check the loaded model, if available.
     """
@@ -139,7 +157,10 @@ def typecheck():
         return
 
     try:
-        model.typecheck()
+        extra_args = [arg[2:] for arg in ctx.args if arg.startswith("--")]
+        extra_args = _parse_list_of_assignments(extra_args)
+
+        model.typecheck(extra_args)
         print("Type checking OK ✅")
     except ModelTypecheckingError as e:
         print("Type checking error 💥")
@@ -188,7 +209,7 @@ def simulate(
         ctx.args,
     )
 
-    config["params"]["save_runs"] = True
+    config["params"]["output_traces"] = True
     config["params"]["length"] = length
     config["params"]["max_run"] = max_trace
 
@@ -254,7 +275,7 @@ def sample(
         None,
         help="Comma-separated list of constant definitions in the format 'name=value' (overwrites config file).",
     ),
-    examples: Optional[str] = typer.Option(
+    tests: Optional[str] = typer.Option(
         None,
         help="Comma-separated list of model predicates describing desired properties in the final state of the execution (overwrites config file).",
     ),
@@ -264,14 +285,14 @@ def sample(
     ),
 ):
     """
-    Generate execution traces that reach the state described by the `examples` properties.
+    Generate execution traces that reach the state described by the `tests` properties.
 
     If extra options are provided, they will be passed directly to the model-checker,
     overwriting values in the config file.
     """
     model, config = _load_model_with_arguments(
         "sample",
-        examples,
+        tests,
         model_path,
         config_path,
         init,
@@ -371,7 +392,7 @@ def _load_model_with_arguments(
     if mode == "check":
         properties_config_name = "invariants"
     elif mode == "sample" or mode == "simulate":
-        properties_config_name = "examples"
+        properties_config_name = "tests"
     else:
         raise ValueError("Unknown checker mode")
 
@@ -395,7 +416,11 @@ def _load_model_with_arguments(
     # Load a model from a given path...
     if model_path:
         model = _create_and_parse_model(
-            model_path, config["init"], config["next"], config["constants"]
+            model_path,
+            config["init"],
+            config["next"],
+            config["constants"],
+            args=config["params"],
         )
 
     # or load a model saved in a pickle file.
@@ -446,11 +471,11 @@ def _run_checker(mode, model, config):
     elif mode == "sample":
         handler = model.sample
         action = "Sampling"
-        properties_config_name = "examples"
+        properties_config_name = "tests"
     elif mode == "simulate":
         handler = model.simulate
         action = "Simulating"
-        properties_config_name = "examples"
+        properties_config_name = "tests"
     else:
         raise ValueError("Unknown checker mode")
 
@@ -544,10 +569,20 @@ def apalache_info(
         print("Apalache JAR file not found")
 
 
+def version_callback(value: str):
+    try:
+        semver.parse(value)
+    except ValueError as e:
+        raise typer.BadParameter(str(e))
+    return value
+
+
 @app_apalache.command()
 def get(
     version: Optional[str] = typer.Argument(
-        const_values.DEFAULT_APALACHE_VERSION, help="Apalache's version."
+        const_values.DEFAULT_APALACHE_VERSION,
+        help="Apalache's version.",
+        callback=version_callback,
     ),
 ):
     """
