@@ -6,7 +6,7 @@ import appdirs
 APALACHE = "apalache"
 TLC = "tlc"
 
-DEFAULT_APALACHE_VERSION = "0.25.10"
+DEFAULT_APALACHE_VERSION = "0.30.1"
 DEFAULT_CHECKERS_LOCATION = os.path.join(appdirs.user_data_dir(__package__), "checkers")
 DEFAULT_APALACHE_LOCATION = os.path.join(DEFAULT_CHECKERS_LOCATION, "apalache")
 
@@ -39,6 +39,10 @@ def apalache_release_url(expected_version):
     return f"https://github.com/informalsystems/apalache/releases/download/v{expected_version}/apalache.zip"
 
 
+def apalache_checksum_url(expected_version: str):
+    return f"https://github.com/informalsystems/apalache/releases/download/v{expected_version}/sha256sum.txt"
+
+
 DEFAULT_TLC_JAR = "jars/tla2tools-v1.8.0.jar"
 
 PARSE = "parse"
@@ -50,6 +54,11 @@ CHECK_CMD = "check"
 TYPECHECK_CMD = "typecheck"
 SIMULATE_CMD = "simulate"
 
+GLOBAL_ARGS = ["features", "out_dir"]
+
+PARSE_CMD_ARGS = ["output"]
+TYPECHECK_CMD_ARGS = ["infer_poly", "output"]
+
 DEFAULT_INVARIANTS = ["Inv"]
 DEFAULT_INIT = "Init"
 DEFAULT_NEXT = "Next"
